@@ -1,11 +1,11 @@
 # -*- python -*-
 #
-#  Copyright 2011 EBI
+#  Copyright 2013
 #
-#  File author(s): Thomas Cokelaer <cokelaer@ebi.ac.uk>
+#  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
 """Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 12 $"
+__version__ = "$Rev: 32 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
@@ -37,3 +37,9 @@ from package import *
 
 import config_tools
 from config_tools import *
+
+import url
+from url import *
+
+#import dependencies
+from dependencies import get_dependencies
